﻿using BlazorStripeTest.Extensions;
using BlazorStripeTest.Models;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using Stripe;
using Stripe.Checkout;
using System;
using System.Collections.Generic;

namespace BlazorStripeTest.Stripe
{
    public class Order
    {

        public static string Create(List<CartItem> cartItems)
        {
            var hostUrl = MyHttpContext.AppBaseUrl;
            // Set the secret key 
            StripeConfiguration.ApiKey = StripeConfig.SecretKey;
            var sessionOptions = new SessionCreateOptions
            {
                CustomerEmail = "testing@aol.com",
                PaymentMethodTypes = new List<string> {
                    "card",
                },
                PaymentIntentData = new SessionPaymentIntentDataOptions
                {
                    CaptureMethod = "manual",
                }, 
            };
            // Add the items to the stripe session
            Int64 totalAmout = 0;
            sessionOptions.LineItems = new List<SessionLineItemOptions>();
            foreach (CartItem cartItem in cartItems)
            {
                sessionOptions.LineItems.Add(new SessionLineItemOptions
                {
                    Name = cartItem.Name,
                    Description = cartItem.ShortDescription,
                    Amount = Convert.ToInt64(cartItem.Price),
                    Currency = StripeConfig.ISOCurrencyCode,
                    Quantity = Convert.ToInt64(cartItem.Quantity),
                });
                totalAmout += Convert.ToInt64(cartItem.Price * cartItem.Quantity);
            }
            // If success the Stripe API redirect to SuccessUrl, if not then to CancelUrl
            // I also pass the totalAmout, the currency code and the order Id. it's easier 
            // to find the order and change its status in the middleware.
            // The amount can also be easily displayed..
            sessionOptions.SuccessUrl = hostUrl
                                      // This is the minimum required by Stripe
                                      + "/api/Stripe/createcharge?sessionid={CHECKOUT_SESSION_ID}" 
                                      // Custom parameters
                                      + "&amout=" + totalAmout.ToString()
                                      + "&currencycode=" + StripeConfig.ISOCurrencyCode
                                      + "&orderId=" + "1"; // Replace 1 by your order Id.
            sessionOptions.CancelUrl = hostUrl
                                     + "/checkout/error?orderId=" + "1";
            var service = new SessionService();
            Session session = service.Create(sessionOptions);
            return "StripePayment/" + session.Id + "/" + totalAmout.ToString();
        }
    }


}
